@@ -8,6 +8,8 @@ from . import indices
 from . import wrappers
 from . import commands
 
+Dataset = datasets.base.Dataset
+
 
 def load(name):
     return registry[name]
@@ -40,3 +42,5 @@ def main(args):
 def main_cli():
     import sys
     main(sys.argv[1:])
+
+__version__ = "0.1.7" # NOTE: keep this in sync with setup.py
